main.cv.folds <- function(train.data, background, folds=10, r.seed=4132016){
  #This function divides the training portion of dataset="data" into k="folds" training and test for cross-validation
  #Set up objects to define the cv.folds.ss
  cv.train.ids<-list()
  cv.test.ids<-list()
  cv.background.train.ids<-list()
  cv.background.test.ids<-list()
  train.data<-train.data
  k <- folds #number of folds
  set.seed(r.seed) #Allows for replication of cv.folds.ss  
  p.ids<-sample(seq(1,dim(train.data)[1]))  # reorder records randomly
  n.test<-floor((1/k)*dim(train.data)[1]) ##Find the size of the test bins (10%)
  p.bin<-seq(1:n.test) ##Initialize the test bin
  back.ids<-sample(seq(1,dim(background)[1]))
  n.back.test<-floor((1/k)*dim(background)[1]) ##Find the size of the test bins (10%), then reduce to balance testing set size below
  back.bin<-seq(1:n.back.test) ##Initialize the background test bin
  for (i in 1:k){
    cv.test.ids[[i]]<-p.ids[p.bin]
    cv.train.ids[[i]]<-seq(1,dim(train.data)[1])[-cv.test.ids[[i]]]
    cv.background.test.ids[[i]]<-back.ids[back.bin[1:length(p.bin)]]
    cv.background.train.ids[[i]]<-seq(1,dim(background)[1])[-cv.background.test.ids[[i]]]
    p.bin<-p.bin+n.test; back.bin<-back.bin+n.back.test
  }
  return(list(folds, cv.test.ids, cv.train.ids, cv.background.test.ids, cv.background.train.ids))
}

tune.cv.folds<-function(ids,folds=10, r.seed=4182016){ #r.seed is fine to repeat each time because it is always selecting from a different collection of randomly ordered rows
  cv.train.ids<-list()
  cv.test.ids<-list()
  cv.background.train.ids<-list()
  cv.background.test.ids<-list()
  k <- folds #number of folds
  set.seed(r.seed) #Allows for replication of cv.folds.ss
  p.ids<-sample(seq(1,length(ids[[1]])))  # reorder records randomly
  n.test<-floor((1/k)*length(ids[[1]])) ##Find the size of the test bins (10%)
  p.bin<-seq(1:n.test) ##Initialize the test bin
  back.ids<-sample(seq(1,length(ids[[2]])))
  n.back.test<-floor((1/k)*length(ids[[2]])) ##Find the size of the test bins (10%), then reduce to balance testing set size below
  back.bin<-seq(1:n.back.test) ##Initialize the background test bin
  for (i in 1:k){
    cv.test.ids[[i]]<-ids[[1]][p.ids[p.bin]]
    cv.train.ids[[i]]<-ids[[1]][seq(1,length(ids[[1]]))[-p.ids[p.bin]]]
    cv.background.test.ids[[i]]<-ids[[2]][back.ids[back.bin[1:length(p.bin)]]]
    cv.background.train.ids[[i]]<-ids[[2]][seq(1,length(ids[[2]]))[-back.ids[back.bin[1:length(p.bin)]]]]
    p.bin<-p.bin+n.test; back.bin<-back.bin+n.back.test
  }
  return(list(folds, cv.test.ids, cv.train.ids, cv.background.test.ids, cv.background.train.ids))
}

cv.objective.fit <- function(param, data, cv.ids, method="rb",type="pca", q=9){
  #This function fits the SDM model to pre-defined cross-validation sets of the data. Used with "optimize" to tune fitting parameters
  #Currently works for range bagging and lobag-oc
  train.data.name<-"train.presence"
  str<-ifelse(type=="pca",".pca","") #Differentiates analysis on pca or rescaled variables
  k <- cv.ids[[1]] #number of folds
  cv.test.ids<-cv.ids[[2]]; cv.train.ids<-cv.ids[[3]]; cv.background.test.ids<-cv.ids[[4]]; cv.background.train.ids<-cv.ids[[5]]
  cv.performance<-rep(NA,k)
  if (method=="rb"){
    for (j in 1:k){
      model.rb.oc <- rb(x=data[[paste(train.data.name,str,sep="")]][cv.train.ids[[j]],1:q], v = 256, d=2, p=param) #Fit model to cv fold j
      #Predict on cv test data
      rb.cv.output.presence <- rb.test(models = model.rb.oc, x.new = data[[paste(train.data.name,str,sep="")]][cv.test.ids[[j]],1:q]) #Predict on hold out test from training, mimics sample size of real data
      rb.cv.output.back <- rb.test(models = model.rb.oc, x.new = data[[paste("train.background",str,sep="")]][cv.background.test.ids[[j]],1:q])#Predict on background data of same sample size as validation test
      cv.performance[j]<-evaluate(p=rb.cv.output.presence,a=rb.cv.output.back)@auc    
    }
  }
  else{
    if (method=="lobag-oc"){
      for (j in 1:k){
        #For lobag-oc the sigma parameter is assumed to be passed on log scale
        model.lobag.oc <- lobag.oc(p=data[[paste(train.data.name,str,sep="")]][cv.train.ids[[j]],1:q], sigma=10^param, n.votes=128)
        #Predict on cv test data
        lobag.cv.output.presence <- predictSvm(model = model.lobag.oc, p = data[[paste(train.data.name,str,sep="")]][cv.test.ids[[j]],1:q])
        #Predict on hold out test from training, mimics sample size of real data
        lobag.cv.output.back <- predictSvm(model = model.lobag.oc, p = data[[paste("train.background",str,sep="")]][cv.background.test.ids[[j]],1:q]) #Predict on background data of same sample size as validation test
        cv.performance[j]<-performance.lobag.oc <- evaluate(p = as.numeric(lobag.cv.output.presence$p.out),
                                                            a = as.numeric(lobag.cv.output.back$p.out))@auc   
      }
    }
    else {
      print("Invalid method")
    }
  }
  return(-mean(cv.performance))
}

