##Script to draw ancillary plots for Killer shrimp, golden mussel and snakehead ms.
library(gplots)

##AUC plot for Golden mussel
test.eval.gm<-readRDS("GM evaluate test.rds")
tiff("Golden mussel AUC plot2.tif",width=3,height=3,units="in",res=300)
#postscript("Golden mussel AUC plot.eps",width=3,height=3)
par(mar=c(3,3,0.5,0.5),mgp=c(2,0.5,0))
plot(test.eval.gm@TPR~test.eval.gm@FPR,xaxs="i",yaxs="i",lwd=2,xlim=c(-0.005,1.005),ylim=c(-0.005,1.005),
     xlab=NA,ylab=NA,las=1,type="l")
lines(test.eval.gm@TPR~test.eval.gm@FPR,lwd=2,col="blue")
mtext(side=1,line=2,"False-positive rate"); mtext(side=2,line=2,"True-positive rate")
segments(x0=0,y0=0,x1=1,y1=1,lty=2)
text(paste("AUC =",round(test.eval.gm@auc,3)),x=0.42,y=0.75,cex=1)
dev.off()

##AUC plot for Killer Shrimp
test.eval.ks<-readRDS("KS evaluate test.rds")
tiff("Killer shrimp AUC plot.tif",width=3,height=3,units="in",res=300)
#postscript("Killer shrimp AUC plot.eps",width=3,height=3)
par(mar=c(3,3,0.5,0.5),mgp=c(2,0.5,0))
plot(test.eval.ks@TPR~test.eval.ks@FPR,xaxs="i",yaxs="i",lwd=2,xlim=c(-0.005,1.005),ylim=c(-0.005,1.005),
     xlab=NA,ylab=NA,las=1,type="l")
lines(test.eval.ks@TPR~test.eval.ks@FPR,lwd=2,col="blue")
mtext(side=1,line=2,"False-positive rate"); mtext(side=2,line=2,"True-positive rate")
segments(x0=0,y0=0,x1=1,y1=1,lty=2)
text(paste("AUC =",round(test.eval.ks@auc,3)),x=0.35,y=0.65,cex=1)
dev.off()

##AUC plot for Snakehead
test.eval.sn<-readRDS("SN evaluate test.rds")
tiff("Snakehead AUC plot.tif",width=3,height=3,units="in",res=300)
#postscript("Snakehead AUC plot.eps",width=3,height=3)
par(mar=c(3,3,0.5,0.5),mgp=c(2,0.5,0))
plot(test.eval.sn@TPR~test.eval.sn@FPR,xaxs="i",yaxs="i",lwd=2,xlim=c(-0.005,1.005),ylim=c(-0.005,1.005),
     xlab=NA,ylab=NA,las=1,type="l")
lines(test.eval.sn@TPR~test.eval.sn@FPR,lwd=2,col="blue")
mtext(side=1,line=2,"False-positive rate"); mtext(side=2,line=2,"True-positive rate")
segments(x0=0,y0=0,x1=1,y1=1,lty=2)
text(paste("AUC =",round(test.eval.sn@auc,3)),x=0.35,y=0.65,cex=1)
dev.off()

##Cross validation AUC and Spatial AUC for all three species
ks.cv.auc<-readRDS("KS-ms-CV-2016.rds"); ks.ss.auc<-readRDS("KS-ms-Spatial-CV-2016.rds")
sn.cv.auc<-readRDS("SN-ms-CV-2016.rds"); sn.ss.auc<-readRDS("SN-ms-Spatial-CV-2016.rds")
gm.cv.auc<-readRDS("GM-ms-CV-2016.rds"); gm.ss.auc<-readRDS("GM-ms-Spatial-CV-2016.rds")
##Value in snakehead spatial, Boyce index is NA, should be 0?
#sn.ss.auc[2,2]<-0
CI<-function(x,limit="Upper"){
  x<-na.omit(x)
  t.t<-t.test(x)
  if(limit=="Upper") return(t.t$conf.int[2])
  if(limit=="Lower") return(t.t$conf.int[1])
}

upper.ci.auc<-c(CI(gm.cv.auc$AUC,limit="Upper"),CI(ks.cv.auc$AUC,limit="Upper"),CI(sn.cv.auc$AUC,limit="Upper"),
                CI(gm.ss.auc$AUC,limit="Upper"),CI(ks.ss.auc$AUC,limit="Upper"),CI(sn.ss.auc$AUC,limit="Upper"))
lower.ci.auc<-c(CI(gm.cv.auc$AUC,limit="Lower"),CI(ks.cv.auc$AUC,limit="Lower"),CI(sn.cv.auc$AUC,limit="Lower"),
                CI(gm.ss.auc$AUC,limit="Lower"),CI(ks.ss.auc$AUC,limit="Lower"),CI(sn.ss.auc$AUC,limit="Lower"))
upper.ci.boyce<-c(CI(gm.cv.auc$Boyce,limit="Upper"),CI(ks.cv.auc$Boyce,limit="Upper"),CI(sn.cv.auc$Boyce,limit="Upper"),
                CI(gm.ss.auc$Boyce,limit="Upper"),CI(ks.ss.auc$Boyce,limit="Upper"),CI(sn.ss.auc$Boyce,limit="Upper"))
lower.ci.boyce<-c(CI(gm.cv.auc$Boyce,limit="Lower"),CI(ks.cv.auc$Boyce,limit="Lower"),CI(sn.cv.auc$Boyce,limit="Lower"),
                CI(gm.ss.auc$Boyce,limit="Lower"),CI(ks.ss.auc$Boyce,limit="Lower"),CI(sn.ss.auc$Boyce,limit="Lower"))

#Bar plot of AUC values
pdf(width=6,height=3,"GM-SH-SH AUC-Boyce Figs.pdf",onefile=T)
tiff(width=6,height=3,units='in',res=300,"GM-KS-SH AUC CV Fig.tif")
par(mar=c(5,4,1.5,0.2),mgp=c(2.5,0.75,0),las=1)
bplot<-barplot2(height=c(mean(gm.cv.auc$AUC),mean(ks.cv.auc$AUC),mean(sn.cv.auc$AUC),
                         mean(gm.ss.auc$AUC),mean(ks.ss.auc$AUC),mean(sn.ss.auc$AUC)),
                space=c(rep(c(1,0.2,0.2),2)),col=c(rep("grey50",3),rep("grey70",3)),ylim=c(0.4,1),xpd=F,
                plot.ci=T,ci.l=lower.ci.auc,
                ci.u=ifelse(upper.ci.auc>1,1,upper.ci.auc),
                ci.lwd=2,ci.width=0.2)
                
par(mgp=c(2.5,2,0))
axis(1,at=bplot,labels=NA)
par(lheight=0.8)
text(x=bplot,y=0.24,
     labels=c("Golden\nmussel\nCV","Killer\nshrimp\nCV","\nSnakehead\nCV","Golden\nmussel\nSpatial","Killer\nshrimp\nSpatial","\nSnakehead\nSpatial"),
     srt=45,xpd=T)
mtext(side=2,line=2.75,"Area under the curve (AUC)",font=1,las=3)
#axis(side=1,at=c((bplot[1]+bplot[2])/2,(bplot[3]+bplot[4])/2,(bplot[5]+bplot[6])/2),labels=c("Mean of\n5 invasives","Spatially\nSegregated","Random\nPoints"),
#     cex.axis=1.3,line=3,tick=F)
dev.off()

#Bar plot of Boyce values
tiff(width=6,height=3,units='in',res=300,"GM-KS-SH Boyce CV Fig.tif")
par(mar=c(5,4,1.5,0.2),mgp=c(2.5,0.75,0),las=1)
bplot<-barplot2(height=c(mean(gm.cv.auc$Boyce),mean(ks.cv.auc$Boyce),mean(sn.cv.auc$Boyce),
                         mean(gm.ss.auc$Boyce),mean(ks.ss.auc$Boyce),mean(sn.ss.auc$Boyce,na.rm=T)),
                space=c(rep(c(1,0.2,0.2),2)),col=c(rep("grey50",3),rep("grey70",3)),ylim=c(-1,1),xpd=F,
                plot.ci=T,ci.l=ifelse(lower.ci.boyce<(-1),-1,lower.ci.boyce),
                ci.u=ifelse(upper.ci.boyce>1,1,upper.ci.boyce),
                ci.lwd=2,ci.width=0.2)

par(mgp=c(2.5,2,0))
axis(1,at=bplot,labels=NA)
par(lheight=0.8)
text(x=bplot,y=-1.5,
     labels=c("Golden\nmussel\nCV","Killer\nshrimp\nCV","\nSnakehead\nCV","Golden\nmussel\nSpatial","Killer\nshrimp\nSpatial","\nSnakehead\nSpatial"),
     srt=45,xpd=T)
mtext(side=2,line=2.75,"Boyce index",font=1,las=3)
#axis(side=1,at=c((bplot[1]+bplot[2])/2,(bplot[3]+bplot[4])/2,(bplot[5]+bplot[6])/2),labels=c("Mean of\n5 invasives","Spatially\nSegregated","Random\nPoints"),
#     cex.axis=1.3,line=3,tick=F)
dev.off()




Bioclim.lab<-c("Mean temp","Mean diurnal range","Isothermal.","Temp seasonality","Max temp","Min temp","Temp range","Temp of wettest",
               "Temp of driest","Temp of warmest","Temp of coldest","Annual precip","Precip of wettest period","Precip of driest period",
               "Precip seasonality","Precip wettest","Precip driest","Precip of warmest","Precip of coldest")
short.lab<-c("Bioclim 1","Bioclim 2","Bioclim 3","Bioclim 4","Bioclim 5","Bioclim 6","Bioclim 7","Bioclim 8","Bioclim 9",
             "Bioclim 10","Bioclim 11","Bioclim 12","Bioclim 13","Bioclim 14","Bioclim 15","Bioclim 16","Bioclim 17",
             "Bioclim 18","Bioclim 19")

##Importance plot for Golden mussel
importance.gm<-readRDS("Golden mussel/GM importance-Oct21.rds")
prop.importance.gm<-importance.gm[,"rel.imp.insample"]/sum(importance.gm[,"rel.imp.insample"])
tiff("Golden mussel importance plot.tif",width=3,height=3,units="in",res=300)
par(mar=c(3,7,0.5,0.5),mgp=c(2,0.5,0))
plot(seq(1:dim(importance.gm)[1])~prop.importance.gm,
     yaxt="n",xlab="Variable importance",ylab=NA)
axis(2,at=seq(1:q),labels=Bioclim.lab,las=1,cex.axis=0.75)
#mtext(side=2,line=5,"Variable name")
dev.off()

#OR

tiff("Golden mussel importance bar plot.tif",width=3,height=3,units="in",res=300)
par(mar=c(7,3,0.5,0.5),mgp=c(2,0.5,0))
bp<-barplot(height=prop.importance.gm,names.arg=NA,
     xaxt="n",ylab="Variable importance",xlab=NA)
axis(1,at=bp,labels=Bioclim.lab,las=2,cex.axis=0.75)
dev.off()

##Importance plot for Killer shrimp
importance.ks<-readRDS("KS importance-Oct2014.rds")
prop.importance.ks<-importance.ks[,"rel.imp.insample"]/sum(importance.ks[,"rel.imp.insample"])
tiff("Killer shrimp importance plot.tif",width=3,height=3,units="in",res=300)
par(mar=c(3,7,0.5,0.5),mgp=c(2,0.5,0))
plot(seq(1:dim(importance.ks)[1])~prop.importance.ks,
     yaxt="n",xlab="Variable importance",ylab=NA)
axis(2,at=seq(1:q),labels=Bioclim.lab,las=1,cex.axis=0.75)
#mtext(side=2,line=5,"Variable name")
dev.off()

#OR

tiff("Killer shrimp importance bar plot.tif",width=3,height=3,units="in",res=300)
par(mar=c(7,3,0.5,0.5),mgp=c(2,0.5,0))
bp<-barplot(height=prop.importance.ks,names.arg=NA,
            xaxt="n",ylab="Variable importance",xlab=NA)
axis(1,at=bp,labels=Bioclim.lab,las=2,cex.axis=0.75)
dev.off()

##Importance plot for Snakehead
importance.sn<-readRDS("Snakehead/SN importance-Oct2014.rds")
prop.importance.sn<-importance.sn[,"rel.imp.insample"]/sum(importance.sn[,"rel.imp.insample"])
tiff("Snakehead importance plot.tif",width=3,height=3,units="in",res=300)
par(mar=c(3,7,0.5,0.5),mgp=c(2,0.5,0))
plot(seq(1:dim(importance.sn)[1])~prop.importance.sn,
     yaxt="n",xlab="Variable importance",ylab=NA)
axis(2,at=seq(1:q),labels=Bioclim.lab,las=1,cex.axis=0.75)
#mtext(side=2,line=5,"Variable name")
dev.off()

#OR

tiff("Snakehead importance bar plot.tif",width=3,height=3,units="in",res=300)
par(mar=c(7,3,0.5,0.5),mgp=c(2,0.5,0))
bp<-barplot(height=prop.importance.sn,names.arg=NA,
            xaxt="n",ylab="Variable importance",xlab=NA)
axis(1,at=bp,labels=Bioclim.lab,las=2,cex.axis=0.75)
dev.off()

output<-data.frame(Golden.mussel.importance=importance.gm[,3],GM.importance.rescale=prop.importance.gm,
                   Killer.shrimp.importance=importance.ks[,3],KS.importance.rescale=importance.ks[,3]/sum(importance.ks[,3]),
                   Snakehead.importance=importance.sn[,3],SN.importance.rescale=prop.importance.sn)
write.csv(output,"GMandKSandSN relative importance.csv")

##Marginal plot for Golden mussel
marginal.gm<-readRDS("Golden mussel/GM marginal plot-Oct2014.rds")
tiff("Golden mussel marginal plots.tif",width=7.5,height=10,units="in",res=300)
par(mfrow=c(5,4),mar=c(3,1,0.1,0),mgp=c(1.6,0.5,0),oma=c(0,3.5,0.4,0.1)) #Saves 20 plots per page
for (i in 1:length(marginal.gm)){
  ## Draws the marginal plot
  scale.margin<-(marginal.gm[[i]]$marginal-min(marginal.gm[[i]]$marginal))/(max(marginal.gm[[i]]$marginal)-min(marginal.gm[[i]]$marginal))
  plot(scale.margin~marginal.gm[[i]]$xi.back,type="l",ylim=c(0,1),ylab=NA,xlab=Bioclim.lab[i],yaxt="n")  ##Creates the marginal plot
  axis(2,labels=F)
  if(i %in% c(1,5,9,13,17)) {axis(2)
                         mtext("Predicted\nniche centrality",side=2,line=1.6,cex=0.8)
  }
}
dev.off()

##Marginal plot for Killer shrimp
marginal.ks<-readRDS("Killer shrimp/KS marginal plot-Oct2014.rds")
tiff("KS marginal plots.tif",width=7.5,height=10,units="in",res=300)
par(mfrow=c(5,4),mar=c(3,1,0.1,0),mgp=c(1.6,0.5,0),oma=c(0,3.5,0.4,0.1)) #Saves 20 plots per page
for (i in 1:length(marginal.ks)){
  ## Draws the marginal plot
  scale.margin<-(marginal.ks[[i]]$marginal-min(marginal.ks[[i]]$marginal))/(max(marginal.ks[[i]]$marginal)-min(marginal.ks[[i]]$marginal))
  plot(scale.margin~marginal.ks[[i]]$xi.back,type="l",ylim=c(0,1),ylab=NA,xlab=Bioclim.lab[i],yaxt="n")  ##Creates the marginal plot
  axis(2,labels=F)
  if(i %in% c(1,5,9,13,17)) {axis(2)
                             mtext("Predicted\nniche centrality",side=2,line=1.6,cex=0.8)
  }
}
dev.off()

marginal.sn<-readRDS("Snakehead/SN marginal plot.rds")
tiff("SN marginal plots.tif",width=7.5,height=10,units="in",res=300)
par(mfrow=c(5,4),mar=c(3,1,0.1,0),mgp=c(1.6,0.5,0),oma=c(0,3.5,0.4,0.1)) #Saves 20 plots per page
for (i in 1:length(marginal.sn)){
  ## Draws the marginal plot
  scale.margin<-(marginal.sn[[i]]$marginal-min(marginal.sn[[i]]$marginal))/(max(marginal.sn[[i]]$marginal)-min(marginal.sn[[i]]$marginal))
  plot(scale.margin~marginal.sn[[i]]$xi.back,type="l",ylim=c(0,1),ylab=NA,xlab=Bioclim.lab[i],yaxt="n")  ##Creates the marginal plot
  axis(2,labels=F)
  if(i %in% c(1,5,9,13,17)) {axis(2)
                             mtext("Predicted\nniche centrality",side=2,line=1.6,cex=0.8)
  }
}
dev.off()
