#Read in required libraries

library(dismo)
library(gbm)
library(raster)
library(rgdal)
library(sp)
library(maptools)
library(latticeExtra)
library(GISTools)

##Set up accessory funtions
source('functions.R')
shadowtext <- function(x, y=NULL, labels, col='darkblue', bg='lightblue',
                       theta= seq(-10,10, length.out=21), r=0.1, ... ) {
  
  xy <- xy.coords(x,y)
  xo <- r*strwidth(labels)
  yo <- r*strheight(labels)
  
  for (i in theta) {
    text( xy$x + xo*0.05*i, xy$y + yo*0.1*i, labels, col=bg, ... )
  }
  text(xy$x, xy$y, labels, col=col, ... )
}

##Set up maps and read in the clipped maps 
##The objects loaded here used to set map boundaries and add geographical information
CRS1 <- CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +towgs84=0,0,0")
GLmap.blue<-raster("Maps from Gust/May2014_Clips_limno_dikero_ToDrew/dikero_lk.tif")
GLmap<-readOGR("Maps from Gust/Oct24_2014_GrassCrp_Hydrilla_LakeOutline_forDrew", layer="GL_lakes_lkdivide_IFR_100k_ClipToBasin_wgs")
GLmap<-spTransform(GLmap,CRS=CRS1)
GLrivers<-readOGR("GL_shoreline",layer="Great_Lakes_Major_Rivers_US_CAN")
GLrivers<-spTransform(GLrivers,CRS=CRS1)
GLcanals<-readOGR("GL_shoreline",layer="Rivers_Canals_Chicago_Morris_All_Final_Modfd_GCS_84")
GLcanals<-spTransform(GLcanals,CRS=CRS1)
GLbasin<-readOGR("Maps from Gust/Oct24_2014_GrassCrp_Hydrilla_LakeOutline_forDrew", layer="GLB_basin_outln_noSLS_IFR_wgs")
GLbasin<-spTransform(GLbasin,CRS=CRS1)
alt<-getData("worldclim",var="alt",res=2.5)
alt.sp<-as(alt,"SpatialGridDataFrame")
alt5<-getData("worldclim",var="alt",res=5)
load("Kramer et al EcoApp data.Rda")

##Labels for the bioclim variables and a plot of these layers
Bioclim.lab<-c("Mean temp","Mean diurnal range","Isothermality","Temp seasonality","Max temp","Min temp","Temp range","Temp of wettest",
               "Temp of driest","Temp of warmest","Temp of coldest","Annual precip","Precip of wettest period","Precip of driest period",
               "Precip seasonality","Precip wettest","Precip driest","Precip of warmest","Precip of coldest")
short.lab<-c("Bioclim 1","Bioclim 2","Bioclim 3","Bioclim 4","Bioclim 5","Bioclim 6","Bioclim 7","Bioclim 8","Bioclim 9",
             "Bioclim 10","Bioclim 11","Bioclim 12","Bioclim 13","Bioclim 14","Bioclim 15","Bioclim 16","Bioclim 17",
             "Bioclim 18","Bioclim 19")
png(width=6,height=6,units="in",res=300,filename="Global climate panel plot.png")
par(mfrow=c(5,4),mar=c(1.5,2.5,1.5,3.75),mgp=c(2,0.5,0))
for (i in 1:19){
  plot(bioclim.rescaled.5min[[i]], main = Bioclim.lab[i],legend.shrink=0.9) # Plot raster
  #plot(GLmap,add=TRUE) # Add Great Lakes outlines
}
dev.off()


##Load map files
##Maps restricted by habitat layers in ArcGIS by Gust Annis
##The clipped maps are available in the archived data and the habitat layers are available online
GM.map<-raster("Maps from Gust/Nov14_2014_GoldenMus_KillerShrmp_Snakehead_forDrew/Golden_Mussel_Oct2014_clip_GLB.tif")
clipped.GM.temp.map<-raster("Maps from Gust/Nov14_2014_GoldenMus_KillerShrmp_Snakehead_forDrew/Golden_Mussel_Oct2014_clip_benthicTemp_gte16.tif")
KS.map<-raster("Maps from Gust/Nov14_2014_GoldenMus_KillerShrmp_Snakehead_forDrew/Killer_shrimp_Oct2014_clip_GLB.tif")
SN.map<-raster("Maps from Gust/Nov14_2014_GoldenMus_KillerShrmp_Snakehead_forDrew/Snakehead_Oct2014_clip_GLB.tif")
clipped.SN.temp.map<-raster("Maps from Gust/Nov14_2014_GoldenMus_KillerShrmp_Snakehead_forDrew/Snakehead_Oct2014_clip_benthictemp_gte18.tif")
clipped.SN.veg.map<-raster("Maps from Gust/Nov14_2014_GoldenMus_KillerShrmp_Snakehead_forDrew/Snakehead_Oct2014_clip_SAV_Wtlnds.tif")

##Set up colors and more geographical information for drawing the maps
KScolors1<-colorRampPalette(c("gray70","yellow3","yellow1","gold","orange","darkorange","red"))
KScolors2<-colorRampPalette(c("white","383","yellow1","gold","orange","darkorange","red"))
altcolors<-colorRampPalette(c("cornsilk3","cornsilk"))
latlonlines<-gridlines(GLbasin)
LP<-as(extent(GLmap)+0.5,"SpatialPolygons"); proj4string(LP)<-CRS1
CP<-as(extent(GLbasin),"SpatialPolygons"); proj4string(CP)<-CRS1
CP1<-as(extent(GLbasin)+0.5,"SpatialPolygons"); proj4string(CP1)<-CRS1
alt.lakes<-crop(alt,extent(CP))
values(alt.lakes)<-ifelse(values(alt.lakes)<0,0,values(alt.lakes))
canada<-getData("GADM", country="CAN", level=1); usa<-getData("GADM",country="USA",level=1)
canada<-spTransform(canada,CRS=CRS1); usa<-spTransform(usa,CRS=CRS1)
GLcanada<-gIntersection(canada,CP1,byid=T); GLusa<-gIntersection(usa,CP1,byid=T); bound<-spRbind(GLcanada,GLusa)
label.coord<-cbind(c(-77.5,-82,-92,-91,-91.75,-89,-86.1,-84.8,-81.2,-78,-75.65),c(47.5,48.2,47.85,45,42.2,42,41.2,43.2,40.8,41.6,42.2))
label.coord.LP<-cbind(c(-77.9,-82,-91.35,-91,-91.3,-89,-86,-84.8,-81,-78,-77),c(46.65,47.7,47.85,45,42.2,42,41.45,43.25,41.5,41.6,42.7))
lake.label.coord<-cbind(c(-77.5,-80.7,-82.3,-87,-87.5),c(43.7,42.4,44.8,43,47.75))
labels<-c("Quebec","Ontario","Minnesota","Wisconsin","Iowa","Illinois","Indiana","Michigan","Ohio","Pennsylvania","New York")
lake.labels<- c("Lake Ontario","Lake Erie","Lake\nHuron","Lake\nMichigan","Lake Superior")                   

#image.plot version of killer shrimp, Great Lakes niche
latlonlines<-gridlines(GLbasin)
tiff(width=6,height=3.9,units="in",res=300,filename="KS full niche EcoApp.tif",compression="lzw")
#postscript(width=6.64,height=4.8,"GC full niche.eps")
par(mar=c(2.5,3.65,0.1,5),mgp=c(1,0.5,0))
plot(CP,axes=T,xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i",las=1,cex.axis=0.8,,yaxs="i",border=NA)
plot(alt.lakes,col=altcolors(50),legend=F,add=T,
     xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i")
lines(latlonlines,col="lightgrey",lty=2,lwd=1.5)
plot(bound,border="tan",lty="19",lwd=1.5,add=T)
plot(KS.map, col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T,
     xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i")
lines(GLrivers,col="lightblue",lty=1,lwd=0.6)
lines(GLcanals,col="lightblue",lty=1,lwd=0.6)
plot(GLmap,col="black",add=T,lwd=1)
plot(KS.map, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i",
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=1),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2.5, cex=0.8))           
text(label.coord,labels,cex=0.7,col="tan3")
text(lake.label.coord[1:5,1],lake.label.coord[1:5,2],lake.labels[1:5],cex=0.6,col="darkblue")
segments(-76.3,49.7,-79.03,49.7); segments(-76.3,49.7,-76.3,49.9); segments(-76.98,49.7,-76.98,49.8); segments(-77.66,49.7,-77.66,49.9)
segments(-78.34,49.7,-78.34,49.8);segments(-79.03,49.7,-79.03,49.9);
text(labels=c("0","100","200","km"),x=c(-79.03,-77.66,-76.3,-75.6),y=c(49.5),cex=0.6)
north.arrow(-76.5,48.2,len=.15,cex.lab=0.5,)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=2.5,las=3,"Latitude",cex=0.8)
dev.off()          

##Global plot of killer shrimp niche in same color scheme
output.ks.world<-raster("~/Desktop/NOAA ENM models/Killer shrimp/Raster map - Dikerogammarus/Dikerogammarus world map Oct2014.asc")
projection(output.ks.world)<-CRS1
latlonlines.w<-gridlines(output.ks.world,easts = c(150,125,100,75,50,25,0,-25,-50,-75,-100,-125,-150),norths=c(75,50,25,0,-25,-50,-75))
world<-gIntersection(wrld_simpl,as(extent(output.ks.world),"SpatialPolygons"),byid=T)
tiff(width=6,height=2.5,units="in",res=300,filename="KS Global map EcoApp.tif",compression="lzw")
par(mar=c(2.5,2.5,0.1,4.5),mgp=c(1,0.5,0))
plot(world)
rect(par("usr")[1], par("usr")[3], par("usr")[2], par("usr")[4], col = "dodgerblue3")
lines(latlonlines.w,col="lightblue",lty=3,lwd=0.5)
plot(output.ks.world,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T)
plot(output.ks.world, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=0.6),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2, cex=0.8))    
plot(world,add=T,lwd=0.25)
axis(side=1,cex.axis=0.8); axis(side=2,las=1,cex.axis=0.8)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=1.75,"Latitude",cex=0.8); #mtext(side=3,line=0.5,"Killer shrimp global niche")
dev.off()

##Global plot of killer shrimp niche in same color scheme with occurrences added
tiff(width=6,height=2.5,units="in",res=300,filename="KS Global and Occurrences EcoApp.tif",compression="lzw")
par(mar=c(2.5,2.5,0.1,4.5),mgp=c(1,0.5,0))
plot(world)
rect(par("usr")[1], par("usr")[3], par("usr")[2], par("usr")[4], col = "dodgerblue3")
lines(latlonlines.w,col="lightblue",lty=3,lwd=0.5)
plot(output.ks.world,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T)
plot(output.ks.world, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=0.6),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2, cex=0.8))    
plot(world,add=T,lwd=0.25)
plot(killer.shrimp[["sp.pts"]],col="black",cex=0.8,pch=3,add=T)
axis(side=1,cex.axis=0.8); axis(side=2,las=1,cex.axis=0.8)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=1.75,"Latitude",cex=0.8); #mtext(side=3,line=0.5,"Killer shrimp global niche")
dev.off()

  

##Golden mussel Great Lakes niche
latlonlines<-gridlines(GLbasin)
tiff(width=6,height=3.9,units="in",res=300,filename="GM full niche EcoApp.tif",compression="lzw")
par(mar=c(2.5,3.65,0.1,5),mgp=c(1,0.5,0))
plot(CP,axes=T,xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i",las=1,cex.axis=0.8,yaxs="i",border=NA)
plot(alt.lakes,col=altcolors(50),legend=F,add=T,
     xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i")
lines(latlonlines,col="lightgrey",lty=2,lwd=1.5)
plot(bound,border="tan",lty="19",lwd=1.5,add=T)
plot(GM.map, col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T,
     xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i")
lines(GLrivers,col="lightblue",lty=1,lwd=0.6)
lines(GLcanals,col="lightblue",lty=1,lwd=0.6)
plot(GLmap,col="black",add=T,lwd=1)
plot(GM.map, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i",
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=0.6),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2.5, cex=0.8))           
text(label.coord,labels,cex=0.7,col="tan3")
text(lake.label.coord[1:5,1],lake.label.coord[1:5,2],lake.labels[1:5],cex=0.6,col="darkblue")
segments(-76.3,49.7,-79.03,49.7); segments(-76.3,49.7,-76.3,49.9); segments(-76.98,49.7,-76.98,49.8); segments(-77.66,49.7,-77.66,49.9)
segments(-78.34,49.7,-78.34,49.8);segments(-79.03,49.7,-79.03,49.9);
text(labels=c("0","100","200","km"),x=c(-79.03,-77.66,-76.3,-75.6),y=c(49.5),cex=0.6)
text("A",x=-92,y=-79)
north.arrow(-76.5,48.2,len=.15,cex.lab=0.5,)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=2.5,las=3,"Latitude",cex=0.8)
dev.off()          


#image plot of golden mussel 16C benthic temp limit
tiff(width=6,height=3.9,units="in",res=300,filename="GM by benthic temp EcoApp.tif",compression="lzw")
par(mar=c(2.5,3.65,0.1,5),mgp=c(1,0.5,0))
plot(LP,axes=T,xlim=c(extent(LP)@xmin,extent(LP)@xmax),ylim=c(extent(LP)@ymin,extent(LP)@ymax),xaxs="i",las=1,cex.axis=0.8,yaxs="i",border=NA)
plot(alt.lakes,col=altcolors(50),legend=F,add=T,xaxs="i")
plot(GLrivers,col="lightblue",lty=1,lwd=1,add=T)
lines(GLcanals,col="lightblue",lty=1,lwd=1)
lines(latlonlines,col="lightgrey",lty=2,lwd=1.5)
plot(GLmap,col="lightblue",add=T,lwd=1)
plot(GLmap.blue,legend=F,add=T,col="lightblue")
plot(bound,border="tan",lty="19",lwd=1.5,add=T)
plot(clipped.GM.temp.map, col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T,
     xlim=c(extent(LP)@xmin,extent(LP)@xmax),ylim=c(extent(LP)@ymin,extent(LP)@ymax),xaxs="i")
plot(clipped.GM.temp.map, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     xlim=c(extent(LP)@xmin,extent(LP)@xmax),ylim=c(extent(LP)@ymin,extent(LP)@ymax),xaxs="i",
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=0.6),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2.5, cex=0.8))
text(label.coord.LP,labels,cex=0.7,col="tan")
text(lake.label.coord[2,1],lake.label.coord[2,2],lake.labels[2],cex=0.6,col="darkblue")
shadowtext(x=lake.label.coord[1,1],y=lake.label.coord[1,2],labels=lake.labels[1],cex=0.6)
#shadowtext(x=lake.label.coord[2,1],y=lake.label.coord[2,2],labels=lake.labels[2],cex=0.6)
shadowtext(x=lake.label.coord[3,1],y=lake.label.coord[3,2],labels=lake.labels[3],cex=0.6)
shadowtext(x=lake.label.coord[4,1],y=lake.label.coord[4,2],labels=lake.labels[4],cex=0.6)
shadowtext(x=lake.label.coord[5,1],y=lake.label.coord[5,2],labels=lake.labels[5],cex=0.6)
segments(-76.3,48.7,-79.03,48.7); segments(-76.3,48.7,-76.3,48.9); segments(-76.98,48.7,-76.98,48.8); segments(-77.66,48.7,-77.66,48.9)
segments(-78.34,48.7,-78.34,48.8);segments(-79.03,48.7,-79.03,48.9)
text(labels=c("0","100","200","km"),x=c(-79.03,-77.66,-76.3,-75.65),y=c(48.5),cex=0.6)
north.arrow(-76.5,47.2,len=.15,cex.lab=0.5,)
plot(GLmap,col=NA,add=T,lwd=0.05)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=2.5,las=3,"Latitude",cex=0.8)
dev.off()

##Global plot of golden mussel niche in same color scheme
output.gm.world<-raster("~/Desktop/NOAA ENM models/Golden mussel/Raster map - Limnoperna/Limnoperna world map Oct2014.asc")
projection(output.gm.world)<-CRS1
latlonlines.w<-gridlines(output.gm.world,easts = c(150,125,100,75,50,25,0,-25,-50,-75,-100,-125,-150),norths=c(75,50,25,0,-25,-50,-75))
world<-gIntersection(wrld_simpl,as(extent(output.gm.world),"SpatialPolygons"),byid=T)
tiff(width=6,height=2.5,units="in",res=300,filename="GM Global map EcoApp.tif",compression="lzw")
par(mar=c(2.5,2.5,0.1,4.5),mgp=c(1,0.5,0))
plot(world)
rect(par("usr")[1], par("usr")[3], par("usr")[2], par("usr")[4], col = "dodgerblue3")
lines(latlonlines.w,col="lightblue",lty=3,lwd=0.5)
plot(output.gm.world,main= "Golden mussel global niche",col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T)
plot(output.gm.world, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=0.6),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2, cex=0.8))    
plot(world,add=T,lwd=0.25)
axis(side=1,cex.axis=0.8); axis(side=2,las=1,cex.axis=0.8)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=1.65,"Latitude",cex=0.8); mtext(side=3,line=0.5,"Golden mussel global niche")
dev.off()

##Global plot of golden mussel niche with occurrences
tiff(width=6,height=2.5,units="in",res=300,filename="GM Global and Occurrences EcoApp.tif",compression="lzw")
par(mar=c(2.5,2.5,0.1,4.5),mgp=c(1,0.5,0))
plot(world)
rect(par("usr")[1], par("usr")[3], par("usr")[2], par("usr")[4], col = "dodgerblue3")
lines(latlonlines.w,col="lightblue",lty=3,lwd=0.5)
plot(output.gm.world,main= "Golden mussel global niche",col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T)
plot(output.gm.world, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=0.6),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2, cex=0.8))    
plot(world,add=T,lwd=0.25)
plot(golden.mussel[["sp.pts"]],col="black",cex=0.8,pch=3,add=T)
axis(side=1,cex.axis=0.8); axis(side=2,las=1,cex.axis=0.8)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=1.65,"Latitude",cex=0.8); mtext(side=3,line=0.5,"Golden mussel global niche")
dev.off()
        


##Snakehead Great Lakes niche
latlonlines<-gridlines(GLbasin)
tiff(width=6,height=3.9,units="in",res=300,filename="SH Full Niche EcoApp.tif",compression='lzw')
par(mar=c(2.5,3.65,0.1,5),mgp=c(1,0.5,0))
plot(CP,axes=T,xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i",las=1,cex.axis=0.8,xaxs="i",yaxs="i",border=NA)
plot(alt.lakes,col=altcolors(50),legend=F,add=T,
     xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i")
lines(latlonlines,col="lightgrey",lty=2,lwd=1.5)
plot(bound,border="tan",lty="19",lwd=1.5,add=T)
plot(SN.map, col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T,
     xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i")
lines(GLrivers,col="lightblue",lty=1,lwd=0.6)
lines(GLcanals,col="lightblue",lty=1,lwd=0.6)
plot(GLmap,col="black",add=T,lwd=1)
plot(SN.map, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     xlim=c(extent(CP)@xmin,extent(CP)@xmax),ylim=c(extent(CP)@ymin,extent(CP)@ymax),xaxs="i",
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=0.6),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2.5, cex=0.8))           
text(label.coord,labels,cex=0.7,col="tan3")
text(lake.label.coord[1:5,1],lake.label.coord[1:5,2],lake.labels[1:5],cex=0.6,col="darkblue")
segments(-76.3,49.7,-79.03,49.7); segments(-76.3,49.7,-76.3,49.9); segments(-76.98,49.7,-76.98,49.8); segments(-77.66,49.7,-77.66,49.9)
segments(-78.34,49.7,-78.34,49.8);segments(-79.03,49.7,-79.03,49.9);
text(labels=c("0","100","200","km"),x=c(-79.03,-77.66,-76.3,-75.6),y=c(49.5),cex=0.6)
north.arrow(-76.5,48.2,len=.15,cex.lab=0.5,)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=2.5,las=3,"Latitude",cex=0.8)
dev.off()          


#image plot of snakehead 18C benthic temp limit
tiff(width=6,height=3.9,units="in",res=300,filename="SH by benthic temp EcoApp.tif",compression="lzw")
par(mar=c(2.5,3.65,0.1,5),mgp=c(1,0.5,0))
plot(LP,axes=T,xlim=c(extent(LP)@xmin,extent(LP)@xmax),ylim=c(extent(LP)@ymin,extent(LP)@ymax),xaxs="i",las=1,cex.axis=0.8,xaxs="i",yaxs="i",border=NA)
plot(alt.lakes,col=altcolors(50),legend=F,add=T,xaxs="i")
plot(GLrivers,col="lightblue",lty=1,lwd=1,add=T)
lines(GLcanals,col="lightblue",lty=1,lwd=1)
lines(latlonlines,col="lightgrey",lty=2,lwd=1.5)
plot(GLmap,col="lightblue",add=T,lwd=1)
plot(GLmap.blue,legend=F,add=T,col="lightblue")
plot(bound,border="tan",lty="19",lwd=1.5,add=T)
plot(clipped.SN.temp.map, col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T,
     xlim=c(extent(LP)@xmin,extent(LP)@xmax),ylim=c(extent(LP)@ymin,extent(LP)@ymax),xaxs="i")
plot(clipped.SN.temp.map, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     xlim=c(extent(LP)@xmin,extent(LP)@xmax),ylim=c(extent(LP)@ymin,extent(LP)@ymax),xaxs="i",
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=0.6),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2.5, cex=0.8))
text(label.coord.LP,labels,cex=0.7,col="tan")
text(lake.label.coord[2,1],lake.label.coord[2,2],lake.labels[2],cex=0.6,col="darkblue")
shadowtext(x=lake.label.coord[1,1],y=lake.label.coord[1,2],labels=lake.labels[1],cex=0.6)
#shadowtext(x=lake.label.coord[2,1],y=lake.label.coord[2,2],labels=lake.labels[2],cex=0.6)
shadowtext(x=lake.label.coord[3,1],y=lake.label.coord[3,2],labels=lake.labels[3],cex=0.6)
shadowtext(x=lake.label.coord[4,1],y=lake.label.coord[4,2],labels=lake.labels[4],cex=0.6)
shadowtext(x=lake.label.coord[5,1],y=lake.label.coord[5,2],labels=lake.labels[5],cex=0.6)
segments(-76.3,48.7,-79.03,48.7); segments(-76.3,48.7,-76.3,48.9); segments(-76.98,48.7,-76.98,48.8); segments(-77.66,48.7,-77.66,48.9)
segments(-78.34,48.7,-78.34,48.8);segments(-79.03,48.7,-79.03,48.9);
text(labels=c("0","100","200","km"),x=c(-79.03,-77.66,-76.3,-75.6),y=c(48.5),cex=0.6)
north.arrow(-76.5,47.2,len=.15,cex.lab=0.5,)
plot(GLmap,col=NA,add=T,lwd=0.05)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=2.5,las=3,"Latitude",cex=0.8)
dev.off()

#image plot of snakehead vegetation limits
tiff(width=6,height=3.9,units="in",res=300,filename="SH by Vegetation EcoApp.tif",compression='lzw')
par(mar=c(2.5,3.65,0.1,5),mgp=c(1,0.5,0))
plot(LP,axes=T,xlim=c(extent(LP)@xmin,extent(LP)@xmax),ylim=c(extent(LP)@ymin,extent(LP)@ymax),xaxs="i",las=1,cex.axis=0.8,xaxs="i",yaxs="i",border=NA)
plot(alt.lakes,col=altcolors(50),legend=F,add=T,xaxs="i")
plot(GLrivers,col="lightblue",lty=1,lwd=1,add=T)
lines(GLcanals,col="lightblue",lty=1,lwd=1)
lines(latlonlines,col="lightgrey",lty=2,lwd=1.5)
plot(GLmap,col="lightblue",add=T,lwd=1)
plot(GLmap.blue,legend=F,add=T,col="lightblue")
plot(bound,border="tan",lty="19",lwd=1.5,add=T)
plot(clipped.SN.veg.map, col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T,
     xlim=c(extent(LP)@xmin,extent(LP)@xmax),ylim=c(extent(LP)@ymin,extent(LP)@ymax),xaxs="i")
plot(clipped.SN.veg.map, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     xlim=c(extent(LP)@xmin,extent(LP)@xmax),ylim=c(extent(LP)@ymin,extent(LP)@ymax),xaxs="i",
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=0.6),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2.5, cex=0.8))
text(label.coord.LP,labels,cex=0.7,col="tan")
text(lake.label.coord[2,1],lake.label.coord[2,2],lake.labels[2],cex=0.6,col="darkblue")
shadowtext(x=lake.label.coord[1,1],y=lake.label.coord[1,2],labels=lake.labels[1],cex=0.6)
#shadowtext(x=lake.label.coord[2,1],y=lake.label.coord[2,2],labels=lake.labels[2],cex=0.6)
shadowtext(x=lake.label.coord[3,1],y=lake.label.coord[3,2],labels=lake.labels[3],cex=0.6)
shadowtext(x=lake.label.coord[4,1],y=lake.label.coord[4,2],labels=lake.labels[4],cex=0.6)
shadowtext(x=lake.label.coord[5,1],y=lake.label.coord[5,2],labels=lake.labels[5],cex=0.6)
segments(-76.3,48.7,-79.03,48.7); segments(-76.3,48.7,-76.3,48.9); segments(-76.98,48.7,-76.98,48.8); segments(-77.66,48.7,-77.66,48.9)
segments(-78.34,48.7,-78.34,48.8);segments(-79.03,48.7,-79.03,48.9);
text(labels=c("0","100","200","km"),x=c(-79.03,-77.66,-76.3,-75.6),y=c(48.5),cex=0.6)
north.arrow(-76.5,47.2,len=.15,cex.lab=0.5,)
plot(GLmap,col=NA,add=T,lwd=0.05)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=2.5,las=3,"Latitude",cex=0.8)
dev.off()

##Global plot of snakehead niche in same color scheme
output.sn.world<-raster("~/Desktop/NOAA ENM models/Snakehead/Raster map - Snakehead/Snakehead world map Oct2014.asc")
projection(output.sn.world)<-CRS1
latlonlines.w<-gridlines(output.sn.world,easts = c(150,125,100,75,50,25,0,-25,-50,-75,-100,-125,-150),norths=c(75,50,25,0,-25,-50,-75))
world<-gIntersection(wrld_simpl,as(extent(output.sn.world),"SpatialPolygons"),byid=T)
tiff(width=1800,height=750,units="px",res=300,filename="SH Global map EcoApp.tif",compression="lzw")
par(mar=c(2.5,2.5,0.1,4.5),mgp=c(1,0.5,0))
plot(world)
rect(par("usr")[1], par("usr")[3], par("usr")[2], par("usr")[4], col = "dodgerblue3")
lines(latlonlines.w,col="lightblue",lty=3,lwd=0.5)
plot(output.sn.world,main= "Snakehead global niche",col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T)
plot(output.sn.world, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=0.6),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2, cex=0.8))    
plot(world,add=T,lwd=0.25)
axis(side=1,cex.axis=0.8); axis(side=2,las=1,cex.axis=0.8)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=1.75,"Latitude",cex=0.8); mtext(side=3,line=0.5,"Snakehead global niche")
dev.off()

##Global plot of snakehead niche in same color scheme with occurrences added
tiff(width=6,height=2.5,units="in",res=300,filename="SH Global and Occurrences EcoApp.tif",compression="lzw")
par(mar=c(2.5,2.5,0.1,4.5),mgp=c(1,0.5,0))
plot(world)
rect(par("usr")[1], par("usr")[3], par("usr")[2], par("usr")[4], col = "dodgerblue3")
lines(latlonlines.w,col="lightblue",lty=3,lwd=0.5)
plot(output.sn.world,main= "Snakehead global niche",col=KScolors1(100),breaks=seq(0,1,length.out=100),legend=F,add=T)
plot(output.sn.world, legend.only=T,col=KScolors1(100),breaks=seq(0,1,length.out=100),legend.shrink=0.9,
     axis.args=list(at=seq(0, 1, length.out=11),labels=seq(0, 1, length.out=11), cex.axis=0.6),
     legend.args=list(text='Niche centrality', side=4, font=2, line=2, cex=0.8))    
plot(world,add=T,lwd=0.25)
plot(snakehead[["sp.pts"]],col="black",cex=0.8,pch=3,add=T)
axis(side=1,cex.axis=0.8); axis(side=2,las=1,cex.axis=0.8)
mtext(side=1,line=1.5,"Longitude",cex=0.8); mtext(side=2,line=1.75,"Latitude",cex=0.8); mtext(side=3,line=0.5,"Snakehead global niche")
dev.off()



