##This script reads in the climate layers for the global data set
##The variables are rescaled
##The geographic data is then saved for use in the analysis

#Packages
library(dismo)
library(raster)
library(rgdal)
library(sp)
library(maptools)
source('Worldclim.R')
source('functions.R')

#Read in world map for reference
CRS1 <- CRS("+proj=latlong +datum=WGS84")
world.map <- readShapePoly("worldmap/gadm1_lev0", proj4string=CRS1, )
#world.tab<-read.csv("worldmap/gadm1_lev0.csv", header=TRUE)


variable.list <- c('bio','tmin','tmax','prec')

i <- 1
for(var in variable.list){
  data0 <- get.world(variable=var,reso=5)   #change to reso to get lower resolution
  save(data0,file=paste(var,'.RData',sep=''))  
  if(i==1){
    data <- stack(data0)
  }
  else {
    data <- stack(data, data0)
  }
  i <- i+1
}

x11(); plot(data)

ClimateCovar<-brick(data)
writeRaster(ClimateCovar, file='World5.grd', bandorder='BIL', overwrite=TRUE)

ClimateCovar.1<-ClimateCovar
##Log transform some of the variables (precipitation, Bio.18,Bio.19)
for (i in c(18:19,44:55)) ClimateCovar.1[[i]]<-log(ClimateCovar[[i]] + 1)
names(ClimateCovar.1)[c(18:19,44:55)]<-c("log.bio.18","log.bio.19","log.Jan.precip","log.Feb.precip", "log.Mar.precip", "log.Apr.precip", "log.May.precip","log.Jun.precip", "log.Jul.precip", "log.Aug.precip", "log.Sep.precip","log.Oct.precip", "log.Nov.precip", "log.Dec.precip")
##Ecdf some others (Bio.12,Bio.13,Bio.14, Bio.16, Bio.17)
for (i in c(12:14,16:17)) ClimateCovar.1[[i]]<-raster.ecdf(ClimateCovar[[i]])
names(ClimateCovar.1)[c(12:14,16:17)]<-c("ecdf.Bio.12", "ecdf.Bio.13", "ecdf.Bio.14","ecdf.Bio.16", "ecdf.Bio.17")

#Now rescale the variables by subtracting mean and dividing by standard deviation, not including ecdf variables
ClimateCovar.rescale<-raster(ClimateCovar.1)
for(i in 1:11) ClimateCovar.rescale<-addLayer(ClimateCovar.rescale,rescale.raster(ClimateCovar.1[[i]]))
for(i in 12:14) ClimateCovar.rescale<-addLayer(ClimateCovar.rescale,ClimateCovar.1[[i]])
for(i in 15) ClimateCovar.rescale<-addLayer(ClimateCovar.rescale,rescale.raster(ClimateCovar.1[[15]]))
for(i in 16:17) ClimateCovar.rescale<-addLayer(ClimateCovar.rescale,ClimateCovar.1[[i]])
for(i in 18:55) ClimateCovar.rescale<-addLayer(ClimateCovar.rescale,rescale.raster(ClimateCovar.1[[i]]))
                                              
names(ClimateCovar.rescale)<-names(ClimateCovar.1)

ClimateCovar.1<-brick(ClimateCovar.1)
writeRaster(ClimateCovar.1, file='World5_transformed.grd', bandorder='BIL', overwrite=TRUE)
ClimateCovar.rescale<-brick(ClimateCovar.rescale)
writeRaster(ClimateCovar.rescale, file='ClimateCovar_rescaled5min.grd', bandorder='BIL', overwrite=TRUE)
save(file='ClimateCovar5min.RData', list=c('ClimateCovar','ClimateCovar.1','ClimateCovar.rescale'))



