# Script to prepare global data shared among all species specific analyses
# Created April 8, 2013 by JMD and AK

# Environmental data is read in as file saved in external script "climate-layers-5min.R" It is already rescaled.
# source('climate-layers-5min.R')  # script to build global climate layers from worldclim database; returns workspace 'ClimateCovar.RData'

ClimateCovar.rescale <- brick("ClimateCovar_rescaled5min.grd")  # load climate data from fixed file to avoid temporary files

data(wrld_simpl)            # load world map outlines

# Boundaries of North America
NorthAm<-extent(-165,-45,15,75)  # define extent of North America for convenient mapping

# Read in Great Lakes map for reference
GLmap<-readOGR("glgis_gl_shore_noaa_70k",layer="glgis_gl_shore_noaa_70k")   # data source: http://www.great-lakes.net/
GLextent<-bbox(GLmap)                                                       # bounding box of Great Lakes

GLbox<-matrix(c(GLextent[1,1],GLextent[1,2],GLextent[1,2],GLextent[1,1],GLextent[1,1],
                GLextent[2,1],GLextent[2,1],GLextent[2,2],GLextent[2,2],GLextent[2,1]),ncol=2)  # convert bounding box of Great Lakes to numeric

GLspoly<-SpatialPolygons(list(Polygons(list(Polygon(GLbox)),1)))            # extract lake boundaries and convert to spatial polygon 
proj4string(GLspoly)<-GLmap@proj4string                              # define projection

# For Great Lakes predictive mapping, we consider bioclim variables 1-19 but not monthly climate variablesReduce predictors to the bio1-bio19, none of the monthly indicators
bioclim.rescaled.5min<-raster(ClimateCovar.rescale)                         # define a new raster brick with the same metadata as ClimateCovar.rescale
for(i in 1:19){
  bioclim.rescaled.5min<-addLayer(bioclim.rescaled.5min,ClimateCovar.rescale[[i]])
}

# Convert to space of principal components to reduce number of predictors and increase independence
set.seed(482013)    # set seed for random selection of points
n.pca<-100000           # number of sample points for pca
bioclim.pca.5min<-prcomp(extract(bioclim.rescaled.5min,randomPoints(bioclim.rescaled.5min,n.pca))) # perform principal components analysis
